@@ -37,7 +37,7 @@
 static pthread_key_t tls_key = -1;
 static pthread_once_t tls_key_once = PTHREAD_ONCE_INIT;
 
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 3)
+#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR < 3)
 # define CUPS_PRINTER_DISCOVERED	0x1000000
 # define CUPS_SERVER_REMOTE_ANY		"_remote_any"
 #endif /* CUPS < 1.3 */
@@ -54,7 +54,7 @@ static pthread_once_t tls_key_once = PTHREAD_ONCE_INIT;
 
 #if HAVE_CUPS_1_6
 # define CUPS_SERVER_REMOTE_PRINTERS	"_remote_printers"
-#endif /* CUPS > 1.5 */
+#endif /* CUPS > 1.6 */
 
 //////////////////////
 // Worker functions //
@@ -1119,17 +1119,17 @@ initcups (void)
 #define STR_CONSTANT(name)					\
   PyDict_SetItemString (d, #name, PyUnicode_FromString (name))
 
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
-#  define INT_16_CONSTANT(newname,oldname)	\
+#if HAVE_CUPS_1_7
+#  define INT_17_CONSTANT(newname,oldname)	\
   INT_CONSTANT_ALIAS(newname,#oldname)
-#  define INT_16_CONSTANT_NEWNAME(newname,oldname)	\
+#  define INT_17_CONSTANT_NEWNAME(newname,oldname)	\
   INT_CONSTANT(newname)
-#else /* CUPS < 1.5 */
-#  define INT_16_CONSTANT(newname,oldname)	\
+#else /* CUPS < 1.7 */
+#  define INT_17_CONSTANT(newname,oldname)	\
   INT_CONSTANT_ALIAS(oldname,#newname)
-#  define INT_16_CONSTANT_NEWNAME(newname,oldname)	\
+#  define INT_17_CONSTANT_NEWNAME(newname,oldname)	\
   INT_CONSTANT_AS(oldname,#newname)
-#endif /* CUPS < 1.5 */
+#endif /* CUPS < 1.7 */
 
   // CUPS printer types
   INT_CONSTANT (CUPS_PRINTER_LOCAL);
@@ -1176,13 +1176,13 @@ initcups (void)
 
   // Selected HTTP status codes
   /* Also define legacy names */
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_7
 #  define INT_HTTP_STATUS_CONSTANT(name)		\
   INT_CONSTANT_ALIAS(HTTP_STATUS_##name, "HTTP_"#name)
-#else /* CUPS < 1.6 */
+#else /* CUPS < 1.7 */
 #  define INT_HTTP_STATUS_CONSTANT(name)		\
   INT_CONSTANT_ALIAS(HTTP_##name, "HTTP_STATUS_"#name)
-#endif /* CUPS < 1.6 */
+#endif /* CUPS < 1.7 */
 
   INT_HTTP_STATUS_CONSTANT (ERROR);
   INT_HTTP_STATUS_CONSTANT (OK);
@@ -1199,9 +1199,9 @@ initcups (void)
   INT_HTTP_STATUS_CONSTANT (SERVICE_UNAVAILABLE);
   INT_HTTP_STATUS_CONSTANT (GATEWAY_TIMEOUT);
   INT_HTTP_STATUS_CONSTANT (NOT_SUPPORTED);
-  INT_16_CONSTANT (HTTP_STATUS_CUPS_AUTHORIZATION_CANCELED,
+  INT_17_CONSTANT (HTTP_STATUS_CUPS_AUTHORIZATION_CANCELED,
 		   HTTP_AUTHORIZATION_CANCELED);
-  INT_16_CONSTANT (HTTP_STATUS_CUPS_PKI_ERROR, HTTP_PKI_ERROR);
+  INT_17_CONSTANT (HTTP_STATUS_CUPS_PKI_ERROR, HTTP_PKI_ERROR);
 
   // PPD UI enum
   INT_CONSTANT (PPD_UI_BOOLEAN);
@@ -1266,13 +1266,13 @@ initcups (void)
 
   // IPP orientations
   /* Also define legacy names */
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_7
 #  define INT_IPP_ORIENT_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_ORIENT_##name, "IPP_"#name)
-#else /* CUPS < 1.6 */
+#else /* CUPS < 1.7 */
 #  define INT_IPP_ORIENT_CONSTANT(name)		\
   INT_CONSTANT_ALIAS(IPP_##name, "IPP_ORIENT_"#name)
-#endif /* CUPS < 1.6 */
+#endif /* CUPS < 1.7 */
 
   INT_IPP_ORIENT_CONSTANT (PORTRAIT);
   INT_IPP_ORIENT_CONSTANT (LANDSCAPE);
@@ -1286,27 +1286,27 @@ initcups (void)
 
   // IPP errors
   /* Also define legacy names */
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_7
 #  define INT_IPP_STATUS_ERROR_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_STATUS_ERROR_##name, "IPP_"#name)
 #  define INT_IPP_STATUS_OK_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_STATUS_##name, "IPP_"#name)
-#else /* CUPS < 1.6 */
+#else /* CUPS < 1.7 */
 #  define INT_IPP_STATUS_ERROR_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_##name, "IPP_STATUS_ERROR_"#name)
 #  define INT_IPP_STATUS_OK_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_##name, "IPP_STATUS_"#name)
-#endif /* CUPS < 1.6 */
+#endif /* CUPS < 1.7 */
 
   INT_IPP_STATUS_OK_CONSTANT (OK);
-  INT_16_CONSTANT (IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED, IPP_OK_SUBST);
-  INT_16_CONSTANT (IPP_STATUS_OK_CONFLICTING, IPP_OK_CONFLICT);
+  INT_17_CONSTANT (IPP_STATUS_OK_IGNORED_OR_SUBSTITUTED, IPP_OK_SUBST);
+  INT_17_CONSTANT (IPP_STATUS_OK_CONFLICTING, IPP_OK_CONFLICT);
   INT_IPP_STATUS_OK_CONSTANT (OK_IGNORED_SUBSCRIPTIONS);
   INT_IPP_STATUS_OK_CONSTANT (OK_IGNORED_NOTIFICATIONS);
   INT_IPP_STATUS_OK_CONSTANT (OK_TOO_MANY_EVENTS);
   INT_IPP_STATUS_OK_CONSTANT (OK_BUT_CANCEL_SUBSCRIPTION);
   INT_IPP_STATUS_OK_CONSTANT (OK_EVENTS_COMPLETE);
-  INT_16_CONSTANT (IPP_STATUS_REDIRECTION_OTHER_SITE,
+  INT_17_CONSTANT (IPP_STATUS_REDIRECTION_OTHER_SITE,
 		   IPP_REDIRECTION_OTHER_SITE);
   INT_IPP_STATUS_ERROR_CONSTANT (BAD_REQUEST);
   INT_IPP_STATUS_ERROR_CONSTANT (FORBIDDEN);
@@ -1318,49 +1318,49 @@ initcups (void)
   INT_IPP_STATUS_ERROR_CONSTANT (GONE);
   INT_IPP_STATUS_ERROR_CONSTANT (REQUEST_ENTITY);
   INT_IPP_STATUS_ERROR_CONSTANT (REQUEST_VALUE);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_DOCUMENT_FORMAT_NOT_SUPPORTED,
+  INT_17_CONSTANT (IPP_STATUS_ERROR_DOCUMENT_FORMAT_NOT_SUPPORTED,
 		   IPP_DOCUMENT_FORMAT);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_ATTRIBUTES_OR_VALUES, IPP_ATTRIBUTES);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_ATTRIBUTES_OR_VALUES, IPP_ATTRIBUTES);
   INT_IPP_STATUS_ERROR_CONSTANT (URI_SCHEME);
   INT_IPP_STATUS_ERROR_CONSTANT (CHARSET);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_CONFLICTING, IPP_CONFLICT);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_CONFLICTING, IPP_CONFLICT);
   INT_IPP_STATUS_ERROR_CONSTANT (COMPRESSION_NOT_SUPPORTED);
   INT_IPP_STATUS_ERROR_CONSTANT (COMPRESSION_ERROR);
   INT_IPP_STATUS_ERROR_CONSTANT (DOCUMENT_FORMAT_ERROR);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_DOCUMENT_ACCESS, IPP_DOCUMENT_ACCESS_ERROR);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_DOCUMENT_ACCESS, IPP_DOCUMENT_ACCESS_ERROR);
   INT_IPP_STATUS_ERROR_CONSTANT (ATTRIBUTES_NOT_SETTABLE);
   INT_IPP_STATUS_ERROR_CONSTANT (IGNORED_ALL_SUBSCRIPTIONS);
   INT_IPP_STATUS_ERROR_CONSTANT (TOO_MANY_SUBSCRIPTIONS);
   INT_IPP_STATUS_ERROR_CONSTANT (IGNORED_ALL_NOTIFICATIONS);
   INT_IPP_STATUS_ERROR_CONSTANT (PRINT_SUPPORT_FILE_NOT_FOUND);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_INTERNAL, IPP_INTERNAL_ERROR);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_INTERNAL, IPP_INTERNAL_ERROR);
   INT_IPP_STATUS_ERROR_CONSTANT (OPERATION_NOT_SUPPORTED);
   INT_IPP_STATUS_ERROR_CONSTANT (SERVICE_UNAVAILABLE);
   INT_IPP_STATUS_ERROR_CONSTANT (VERSION_NOT_SUPPORTED);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_DEVICE, IPP_DEVICE_ERROR);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_TEMPORARY, IPP_TEMPORARY_ERROR);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_NOT_ACCEPTING_JOBS, IPP_NOT_ACCEPTING);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_BUSY, IPP_PRINTER_BUSY);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_JOB_CANCELED, IPP_ERROR_JOB_CANCELED);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_DEVICE, IPP_DEVICE_ERROR);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_TEMPORARY, IPP_TEMPORARY_ERROR);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_NOT_ACCEPTING_JOBS, IPP_NOT_ACCEPTING);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_BUSY, IPP_PRINTER_BUSY);
+  INT_17_CONSTANT (IPP_STATUS_ERROR_JOB_CANCELED, IPP_ERROR_JOB_CANCELED);
   INT_IPP_STATUS_ERROR_CONSTANT (MULTIPLE_JOBS_NOT_SUPPORTED);
   INT_IPP_STATUS_ERROR_CONSTANT (PRINTER_IS_DEACTIVATED);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_CUPS_AUTHENTICATION_CANCELED,
+  INT_17_CONSTANT (IPP_STATUS_ERROR_CUPS_AUTHENTICATION_CANCELED,
 		   IPP_AUTHENTICATION_CANCELED);
-  INT_16_CONSTANT (IPP_STATUS_ERROR_CUPS_PKI, IPP_PKI_ERROR);
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 5)
-  INT_16_CONSTANT (IPP_STATUS_ERROR_CUPS_UPGRADE_REQUIRED,
+  INT_17_CONSTANT (IPP_STATUS_ERROR_CUPS_PKI, IPP_PKI_ERROR);
+#if HAVE_CUPS_1_5
+  INT_17_CONSTANT (IPP_STATUS_ERROR_CUPS_UPGRADE_REQUIRED,
 		   IPP_UPGRADE_REQUIRED);
 #endif /* CUPS >= 1.5 */
 
   // IPP states
   /* Also define legacy names */
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_7
 #  define INT_IPP_STATE_CONSTANT(name)	\
   INT_CONSTANT_ALIAS(IPP_STATE_##name, "IPP_"#name)
-#else /* CUPS < 1.6 */
+#else /* CUPS < 1.7 */
 #  define INT_IPP_STATE_CONSTANT(name)		\
   INT_CONSTANT_ALIAS(IPP_##name, "IPP_STATE_"#name)
-#endif /* CUPS < 1.6 */
+#endif /* CUPS < 1.7 */
 
   INT_IPP_STATE_CONSTANT (ERROR);
   INT_IPP_STATE_CONSTANT (IDLE);
@@ -1387,13 +1387,13 @@ initcups (void)
   INT_CONSTANT (IPP_TAG_MIMETYPE);
 
   // IPP operations
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_7
 #  define INT_IPP_OP_CONSTANT(name)		\
   INT_CONSTANT(IPP_OP_##name)
-#else /* CUPS < 1.6 */
+#else /* CUPS < 1.7 */
 #  define INT_IPP_OP_CONSTANT(name)					\
   INT_CONSTANT_AS(IPP_##name, "IPP_OP_"#name)
-#endif /* CUPS < 1.6 */
+#endif /* CUPS < 1.7 */
 
   INT_IPP_OP_CONSTANT (PRINT_JOB);
   INT_IPP_OP_CONSTANT (PRINT_URI);
@@ -1414,16 +1414,16 @@ initcups (void)
   INT_IPP_OP_CONSTANT (SET_PRINTER_ATTRIBUTES);
   INT_IPP_OP_CONSTANT (SET_JOB_ATTRIBUTES);
   INT_IPP_OP_CONSTANT (GET_PRINTER_SUPPORTED_VALUES);
-  INT_16_CONSTANT (IPP_OP_CREATE_PRINTER_SUBSCRIPTIONS,
+  INT_17_CONSTANT (IPP_OP_CREATE_PRINTER_SUBSCRIPTIONS,
 		   IPP_CREATE_PRINTER_SUBSCRIPTION);
-  INT_16_CONSTANT (IPP_OP_CREATE_JOB_SUBSCRIPTIONS,
+  INT_17_CONSTANT (IPP_OP_CREATE_JOB_SUBSCRIPTIONS,
 		   IPP_CREATE_JOB_SUBSCRIPTION);
   INT_IPP_OP_CONSTANT (GET_SUBSCRIPTIONS);
   INT_IPP_OP_CONSTANT (RENEW_SUBSCRIPTION);
   INT_IPP_OP_CONSTANT (CANCEL_SUBSCRIPTION);
   INT_IPP_OP_CONSTANT (GET_NOTIFICATIONS);
   INT_IPP_OP_CONSTANT (SEND_NOTIFICATIONS);
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_6
   INT_IPP_OP_CONSTANT (GET_RESOURCE_ATTRIBUTES);
   INT_IPP_OP_CONSTANT (GET_RESOURCE_DATA);
   INT_IPP_OP_CONSTANT (GET_RESOURCES);
@@ -1445,31 +1445,33 @@ initcups (void)
   INT_IPP_OP_CONSTANT (RESUME_JOB);
   INT_IPP_OP_CONSTANT (PROMOTE_JOB);
   INT_IPP_OP_CONSTANT (SCHEDULE_JOB_AFTER);
-#if CUPS_VERSION_MAJOR > 1 || (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 6)
+#if HAVE_CUPS_1_6
   INT_IPP_OP_CONSTANT (CANCEL_JOBS);
   INT_IPP_OP_CONSTANT (CANCEL_MY_JOBS);
   INT_IPP_OP_CONSTANT (RESUBMIT_JOB);
   INT_IPP_OP_CONSTANT (CLOSE_JOB);
   INT_IPP_OP_CONSTANT (IDENTIFY_PRINTER);
   INT_IPP_OP_CONSTANT (VALIDATE_DOCUMENT);
-  INT_IPP_OP_CONSTANT (SEND_HARDCOPY_DOCUMENT);
 #endif /* CUPS >= 1.6 */
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_DEFAULT, CUPS_GET_DEFAULT);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PRINTERS, CUPS_GET_PRINTERS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_ADD_MODIFY_PRINTER,
+#if HAVE_CUPS_1_7
+  INT_IPP_OP_CONSTANT (SEND_HARDCOPY_DOCUMENT);
+#endif /* CUPS >= 1.7 */
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_DEFAULT, CUPS_GET_DEFAULT);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PRINTERS, CUPS_GET_PRINTERS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_ADD_MODIFY_PRINTER,
 			   CUPS_ADD_MODIFY_PRINTER);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_DELETE_PRINTER, CUPS_DELETE_PRINTER);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_CLASSES, CUPS_GET_CLASSES);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_ADD_MODIFY_CLASS, CUPS_ADD_MODIFY_CLASS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_DELETE_CLASS, CUPS_DELETE_CLASS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_ACCEPT_JOBS, CUPS_ACCEPT_JOBS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_REJECT_JOBS, CUPS_REJECT_JOBS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_SET_DEFAULT, CUPS_SET_DEFAULT);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PPDS, CUPS_GET_PPDS);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_MOVE_JOB, CUPS_MOVE_JOB);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_AUTHENTICATE_JOB, CUPS_AUTHENTICATE_JOB);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PPD, CUPS_GET_PPD);
-  INT_16_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_DOCUMENT, CUPS_GET_DOCUMENT);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_DELETE_PRINTER, CUPS_DELETE_PRINTER);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_CLASSES, CUPS_GET_CLASSES);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_ADD_MODIFY_CLASS, CUPS_ADD_MODIFY_CLASS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_DELETE_CLASS, CUPS_DELETE_CLASS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_ACCEPT_JOBS, CUPS_ACCEPT_JOBS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_REJECT_JOBS, CUPS_REJECT_JOBS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_SET_DEFAULT, CUPS_SET_DEFAULT);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PPDS, CUPS_GET_PPDS);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_MOVE_JOB, CUPS_MOVE_JOB);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_AUTHENTICATE_JOB, CUPS_AUTHENTICATE_JOB);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_PPD, CUPS_GET_PPD);
+  INT_17_CONSTANT_NEWNAME (IPP_OP_CUPS_GET_DOCUMENT, CUPS_GET_DOCUMENT);
 
   // Limits
   INT_CONSTANT (IPP_MAX_NAME);
